#!/bin/bash
#
# Script to configure khanat server
#    Copyright (C) 2017  AleaJactaEst
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

declare DEBUG=""

usage()
{
cat << EOF
usage:$0 [options]
  Configure Patch Server

options:
  -h, --help              : Show this help
  -d, --debug             : Show debug message
  --jobs=[INTEGER]        : Number thread for path_gen
EOF
}

while test $# -gt 0
do
   case "$1" in
      -h|--help)
         usage
         exit 1
         ;;
      -d|--debug)
         DEBUG="-d"
         shift
         ;;
      --client-dir=*)
        DIRCLIENT="${1#*=}"
        shift
        ;;
      --jobs=*)
        MULTITHREAD="$1"
        shift
        ;;
      *)
         msg_error "[$(basename $0):$LINENO] options '$1' not recognize"
         usage
         exit 1
         ;;
   esac
done

/opt/ext/servercontainer_configure_link.sh $DEBUG || exit 2
/opt/ext/servercontainer_configure_mysql.sh $DEBUG || exit 2
sync
/opt/ext/servercontainer_configure_apache.sh $DEBUG || exit 2
/opt/ext/servercontainer_configure_world.sh $DEBUG || exit 2
su -c "/opt/ext/servercontainer_configure_khanat.sh $DEBUG" gameserver || exit 2
su -c "/opt/ext/servercontainer_configure_patch.sh $DEBUG $MULTITHREAD" gameserver || exit 2
su -c "/opt/ext/servercontainer_configure_launcher.sh $DEBUG" gameserver || exit 2
su -c 'touch /home/gameserver/khanat/step_configure.ok' gameserver || exit 2
sync
exit 0

