#!/bin/bash
#
# Configure Launcher
#    Copyright (C) 2017  AleaJactaEst
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

usage()
{
cat << EOF
usage:$0 [options]
  Configure Launcher (certificate)

options:
  -h, --help              : Show this help
  -d, --debug             : Show debug message
EOF
}

#####################
# MAIN
#####################
source /opt/ext/servercontainer_function.sh
msg_info "[$(basename $0):$LINENO] => START"

while test $# -gt 0
do
   case "$1" in
      -h|--help)
         usage
         exit 1
         ;;
      -d|--debug)
         set_debug 1
         shift
         ;;
      *)
         msg_error "options '$1' not recognize"
         usage
         exit 1
         ;;
   esac
done

####################################
# Load Environment
####################################
msg_debug "Load environment"
if [[ ! -f /opt/khanat_config.sh ]]
then
   echo "ERROR - missing /opt/khanat_config.sh"
   exit 2
fi
source /opt/khanat_config.sh

if [[ ! -f /home/gameserver/.bashrc ]]
then
   echo "ERROR - missing /home/gameserver/.bashrc"
   exit 2
fi
source /home/gameserver/.bashrc


####################################
# opennel-pymanager
####################################
msg_info "[$(basename $0):$LINENO] install/update opennel-pymanager"
last_pymanager_package=$(ls /opt/ref/opennel_manager/opennel_manager*.whl | sort -r | head -n 1)
if [[ -n "$last_pymanager_package" ]]
then
  pip3 show pymanager
  if [[ $? -eq 0 ]]
  then
    msg_info "[$(basename $0):$LINENO] uninstall opennel-pymanager"
    pip3 uninstall -y pymanager
  fi
  msg_info "[$(basename $0):$LINENO] install opennel-pymanager"
  pip3 install $last_pymanager_package
else
  msg_error "[$(basename $0):$LINENO] no package opennel-pymanager"
  find / -name "opennel_manager*.whl"
  exit 3
fi

####################################
# End
####################################
msg_info "[$(basename $0):$LINENO] => END"

